@@ -9,7 +9,7 @@
 #include <CalendarSupport/FreeBusyItemModel>
 
 #include <KCalendarCore/FreeBusyPeriod>
-#include <KGantt/KGanttGraphicsView>
+#include <KGanttGraphicsView>
 
 #include <KLocalizedString>
 
@@ -86,3 +86,5 @@ QString FreeBusyGanttProxyModel::tooltipify(const KCalendarCore::FreeBusyPeriod
     toolTip += QStringLiteral("</qt>");
     return toolTip;
 }
+
+#include "moc_freebusyganttproxymodel.cpp"
