@@ -5,19 +5,19 @@
  *
  */
 
-#ifndef RESOURCEITEM_H
-#define RESOURCEITEM_H
+#pragma once
 
-#include <KLDAP/LdapClient>
+#include <KLDAPWidgets/LdapClient>
 
-#include <KLDAP/LdapObject>
+#include <KLDAPCore/LdapObject>
 
+#include <QList>
 #include <QSharedPointer>
 #include <QStringList>
 #include <QVariant>
-#include <QVector>
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class ResourceItem : public QObject
 {
     Q_OBJECT
@@ -29,24 +29,27 @@ public:
     /**
       A shared pointer to an ResourceItem object.
     */
-    typedef QSharedPointer<ResourceItem> Ptr;
+    using Ptr = QSharedPointer<ResourceItem>;
 
-    ResourceItem(const KLDAP::LdapDN &dn, const QStringList &attrs, const KLDAP::LdapClient &ldapClient, const ResourceItem::Ptr &parent = ResourceItem::Ptr());
-    ~ResourceItem();
+    ResourceItem(const KLDAPCore::LdapDN &dn,
+                 const QStringList &attrs,
+                 const KLDAPWidgets::LdapClient &ldapClient,
+                 const ResourceItem::Ptr &parent = ResourceItem::Ptr());
+    ~ResourceItem() override;
 
-    Q_REQUIRED_RESULT ResourceItem::Ptr child(int number);
-    Q_REQUIRED_RESULT int childCount() const;
-    Q_REQUIRED_RESULT int columnCount() const;
-    Q_REQUIRED_RESULT QVariant data(int column) const;
-    Q_REQUIRED_RESULT QVariant data(const QString &column) const;
-    Q_REQUIRED_RESULT bool insertChild(int position, const ResourceItem::Ptr &item);
-    Q_REQUIRED_RESULT ResourceItem::Ptr parent();
-    Q_REQUIRED_RESULT bool removeChildren(int position, int count);
-    Q_REQUIRED_RESULT int childNumber() const;
+    [[nodiscard]] ResourceItem::Ptr child(int number);
+    [[nodiscard]] int childCount() const;
+    [[nodiscard]] int columnCount() const;
+    [[nodiscard]] QVariant data(int column) const;
+    [[nodiscard]] QVariant data(const QString &column) const;
+    [[nodiscard]] bool insertChild(int position, const ResourceItem::Ptr &item);
+    [[nodiscard]] ResourceItem::Ptr parent();
+    [[nodiscard]] bool removeChildren(int position, int count);
+    [[nodiscard]] int childNumber() const;
 
 private:
     QList<ResourceItem::Ptr> childItems;
-    QVector<QVariant> itemData;
+    QList<QVariant> itemData;
     ResourceItem::Ptr parentItem;
 
 Q_SIGNALS:
@@ -61,19 +64,19 @@ public:
     /* Returns the ldapObject, that is used as data source.
      *
      */
-    const KLDAP::LdapObject &ldapObject() const;
+    const KLDAPCore::LdapObject &ldapObject() const;
 
     /* Set the ldapObject, either directly via this function
      * or use startSearch to request the ldapServer for the ldapObject
      * with the dn specified via the constructor.
      *
      */
-    void setLdapObject(const KLDAP::LdapObject &);
+    void setLdapObject(const KLDAPCore::LdapObject &);
 
     /* The used ldapClient.
      *
      */
-    const KLDAP::LdapClient &ldapClient() const;
+    const KLDAPWidgets::LdapClient &ldapClient() const;
 
     /* Start querying the ldapServer for a object that name is dn
      *
@@ -84,12 +87,12 @@ private:
     /* data source
      *
      */
-    KLDAP::LdapObject mLdapObject;
+    KLDAPCore::LdapObject mLdapObject;
 
     /* dn of the ldapObject
      *
      */
-    const KLDAP::LdapDN dn;
+    const KLDAPCore::LdapDN dn;
 
     /* Attributes of the ldapObject to request and the header of the Item
      *
@@ -99,18 +102,17 @@ private:
     /* ldapClient to request
      *
      */
-    KLDAP::LdapClient mLdapClient;
+    KLDAPWidgets::LdapClient mLdapClient;
 
 private:
     /* Answer of the LdapServer for the given dn
      *
      */
-    void slotLDAPResult(const KLDAP::LdapClient &, const KLDAP::LdapObject &);
+    void slotLDAPResult(const KLDAPWidgets::LdapClient &, const KLDAPCore::LdapObject &);
 };
 }
 
 //@cond PRIVATE
-Q_DECLARE_TYPEINFO(IncidenceEditorNG::ResourceItem::Ptr, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(IncidenceEditorNG::ResourceItem::Ptr, Q_RELOCATABLE_TYPE);
 Q_DECLARE_METATYPE(IncidenceEditorNG::ResourceItem::Ptr)
 //@endcond
-#endif // RESOURCEITEM_H
